STATFOX
========

.. image:: https://raw.githubusercontent.com/DevinWhitten/STATFOX/master/png/STAT_FOX_v2.png
    :target: https://raw.githubusercontent.com/DevinWhitten/STATFOX/master/png/STAT_FOX_v2.png

STATFOX is a Python toolkit for advanced statistical and exploratory analysis procedures.

Look how easy it is to use:




Features
--------

- Robust statistical functions
- Kernel density estimation aided PDF determination
- Binned statistics with masking support
- Arbitrary function Bayesian maximization

Installation
------------

  pip install STATFOX


Contribute
----------

- Source Code: github.com/DevinWhitten/STATFOX

Support
-------

If you are having issues, please let us know.
We have a mailing list located at: devin.d.whitten@gmail.com

License
-------

The project is licensed under the MIT license.
